﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Imaging;

namespace Kresleni
{
    public partial class Form1 : Form
    {
        const int LineTool = 0;
        const int RectangleTool = 1;
        const int EllipseTool = 2;

        public Form1()
        {
            InitializeComponent();
            pictureBox_SizeChanged(null, null);

            int w = preview.ClientRectangle.Width;
            int h = preview.ClientRectangle.Height;
            preview.Image = new Bitmap (w, h);

            showPreview();

            comboBox1.SelectedIndex = EllipseTool;
        }

        private void showPreview()
        {
           int w = preview.ClientRectangle.Width;
           int h = preview.ClientRectangle.Height;
           Graphics g = Graphics.FromImage(preview.Image);
           Brush b = Brushes.White;
           g.FillRectangle(b, 0, 0, w, h);
           Draw(g, pen, brush, 4, 4, w - 4, h - 4, comboBox1.SelectedIndex);
           preview.Invalidate();
        }

        private void Draw(Graphics g, Pen p, Brush b,
                          int x1, int y1, int x2, int y2,
                          int tool)
        {
            if (x2 < x1) { int t = x2; x2 = x1; x1 = t; }
            if (y2 < y1) { int t = y2; y2 = y1; y1 = t; }
            
            switch (tool)
            {
                case LineTool:
                    g.DrawLine(p, x1, y1, x2, y2);
                    break;
                case RectangleTool:
                    if (b != null)
                        g.FillRectangle(b, x1, y1, x2 - x1, y2 - y1);
                    g.DrawRectangle(p, x1, y1, x2 - x1, y2 - y1);
                    break;
                case EllipseTool:
                    if (b != null)
                        g.FillEllipse(b, x1, y1, x2 - x1, y2 - y1);
                    g.DrawEllipse(p, x1, y1, x2 - x1, y2 - y1);
                    break;
            }
        }

        private void pictureBox_SizeChanged(object sender, EventArgs e)
        {
            int w = pictureBox.ClientSize.Width;
            int h = pictureBox.ClientSize.Height;
            if (w > 0 && h > 0)
            {
                Bitmap t = null;
                if (pictureBox.Image != null)
                {
                    t = new Bitmap(pictureBox.Image);
                    w = Math.Max(w, pictureBox.Image.Width);
                    h = Math.Max(h, pictureBox.Image.Height);
                }

                pictureBox.Image = new Bitmap(w, h);

                Graphics g = Graphics.FromImage(pictureBox.Image);
                Brush b = Brushes.White;
                g.FillRectangle(b, 0, 0, w, h);

                if (t != null)
                   g.DrawImage(t, 0, 0);
            }
        }



        private void runMenu_Click(object sender, EventArgs e)
        {
            Graphics g = Graphics.FromImage (pictureBox.Image);
            Pen p = Pens.Red;
            g.DrawLine (p, 0, 0, 100, 200);
            pictureBox.Invalidate ();
        }

        private int X0, Y0;
        private bool stisknuto = false;
        private Bitmap save;

        private void pictureBox_MouseDown(object sender, MouseEventArgs e)
        {
            X0 = e.X;
            Y0 = e.Y;
            stisknuto = true;
            save = new Bitmap (pictureBox.Image);
        }

        private void pictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            if (stisknuto)
            {
                Graphics g = Graphics.FromImage(pictureBox.Image);
                if (save != null)
                   g.DrawImage(save, 0, 0);
                Pen p = new Pen (Color.Blue);
                Draw (g, p, null, X0, Y0, e.X, e.Y, comboBox1.SelectedIndex);
                // g.DrawLine(p, X0, Y0, e.X, e.Y);
                pictureBox.Invalidate();
            }
        }


        private void pictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            if (stisknuto)
            {
                stisknuto = false;
                Graphics g = Graphics.FromImage(pictureBox.Image);
                if (save != null)
                    g.DrawImage(save, 0, 0);
                save = null;
                // Pen p = new Pen(Color.Red);
                // p.Width = 3;
                // g.DrawLine(pen, X0, Y0, e.X, e.Y);
                Draw(g, pen, brush, X0, Y0, e.X, e.Y, comboBox1.SelectedIndex);
                pictureBox.Invalidate();
            }
        }

        Pen pen = new Pen (Color.SlateGray);
        Brush brush = new SolidBrush (Color.Gray);

        private void panel1_MouseDown(object sender, MouseEventArgs e)
        {
            // Control panel = (Control) sender;
            Control panel = sender as Control;
            if (e.Button == MouseButtons.Left)
                pen = new Pen(panel.BackColor);
            else if (e.Button == MouseButtons.Right)
                brush = new SolidBrush (panel.BackColor);
            else if (e.Button == MouseButtons.Middle)
            {
                colorDialog1.Color = panel.BackColor;
                if (colorDialog1.ShowDialog() == DialogResult.OK)
                {
                    panel.BackColor = colorDialog1.Color;
                    pen = new Pen(panel.BackColor);
                }
            }
            showPreview();
        }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            showPreview();
        }


        private void quitMenu_Click(object sender, EventArgs e)
        {
            this.Close ();
        }

        private int cnt = 2;

        private void newButtonMenu_Click(object sender, EventArgs e)
        {
            Panel p = new Panel ();
            p.BackColor = Color.Blue;
            p.Parent = toolPanel;
            // toolPanel.Controls.Add(p);

            cnt ++;
            p.Left = panel1.Left + (cnt - 1) * (panel2.Left - panel1.Left);
            p.Top = panel1.Top;
            p.Height = panel1.Height;
            p.Width = panel1.Width;

            p.MouseDown += this.panel1_MouseDown;
        }

        private void openMenu_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                Bitmap b = new Bitmap (openFileDialog1.FileName);
                Graphics g = Graphics.FromImage(pictureBox.Image);
                g.DrawImage (b, 0, 0);
                pictureBox.Invalidate();

            }
        }

        private void saveMenu_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                // using System.Drawing.Imaging;
                pictureBox.Image.Save(saveFileDialog1.FileName,
                                      ImageFormat.Bmp);
            }
        }


    }
}
